@@ -1,23 +1,23 @@
-import copy
 import json
+from typing import Optional
 
 from aiohttp import web
-from aiohttp_session import get_session
 
 from ai.backend.client.config import APIConfig
 from ai.backend.client.session import AsyncSession as APISession
+from ai.backend.common.web.session import get_session
 
 from . import user_agent
 
 
 async def get_api_session(
     request: web.Request,
-    api_endpoint: str = None,
+    override_api_endpoint: Optional[str] = None,
 ) -> APISession:
     config = request.app["config"]
-    if api_endpoint is not None:
-        config = copy.deepcopy(config)
-        config["api"]["endpoint"] = api_endpoint
+    api_endpoint = config["api"]["endpoint"][0]
+    if override_api_endpoint is not None:
+        api_endpoint = override_api_endpoint
     session = await get_session(request)
     if not session.get("authenticated", False):
         raise web.HTTPUnauthorized(
@@ -51,33 +51,33 @@ async def get_api_session(
             content_type="application/problem+json",
         )
     ak, sk = token["access_key"], token["secret_key"]
-    config = APIConfig(
+    api_config = APIConfig(
         domain=config["api"]["domain"],
-        endpoint=config["api"]["endpoint"],
+        endpoint=api_endpoint,
         endpoint_type="api",
         access_key=ak,
         secret_key=sk,
         user_agent=user_agent,
-        skip_sslcert_validation=not config["api"].get("ssl-verify", True),
+        skip_sslcert_validation=not config["api"]["ssl_verify"],
     )
-    return APISession(config=config, proxy_mode=True)
+    return APISession(config=api_config, proxy_mode=True)
 
 
 async def get_anonymous_session(
     request: web.Request,
-    api_endpoint: str = None,
+    override_api_endpoint: Optional[str] = None,
 ) -> APISession:
     config = request.app["config"]
-    if api_endpoint is not None:
-        config = copy.deepcopy(config)
-        config["api"]["endpoint"] = api_endpoint
-    config = APIConfig(
+    api_endpoint = config["api"]["endpoint"][0]
+    if override_api_endpoint is not None:
+        api_endpoint = override_api_endpoint
+    api_config = APIConfig(
         domain=config["api"]["domain"],
-        endpoint=config["api"]["endpoint"],
+        endpoint=api_endpoint,
         endpoint_type="api",
         access_key="",
         secret_key="",
         user_agent=user_agent,
-        skip_sslcert_validation=not config["api"].get("ssl-verify", True),
+        skip_sslcert_validation=not config["api"]["ssl_verify"],
     )
-    return APISession(config=config, proxy_mode=True)
+    return APISession(config=api_config, proxy_mode=True)
