@@ -470,12 +470,12 @@ async def server_main(
         config["session"]["redis"]["port"]
     ).with_password(config["session"]["redis"]["password"]) / str(config["session"]["redis"]["db"])
     keepalive_options = {}
-    if hasattr(socket, "TCP_KEEPIDLE"):
-        keepalive_options[socket.TCP_KEEPIDLE] = 20
-    if hasattr(socket, "TCP_KEEPINTVL"):
-        keepalive_options[socket.TCP_KEEPINTVL] = 5
-    if hasattr(socket, "TCP_KEEPCNT"):
-        keepalive_options[socket.TCP_KEEPCNT] = 3
+    if (_TCP_KEEPIDLE := getattr(socket, "TCP_KEEPIDLE", None)) is not None:
+        keepalive_options[_TCP_KEEPIDLE] = 20
+    if (_TCP_KEEPINTVL := getattr(socket, "TCP_KEEPINTVL", None)) is not None:
+        keepalive_options[_TCP_KEEPINTVL] = 5
+    if (_TCP_KEEPCNT := getattr(socket, "TCP_KEEPCNT", None)) is not None:
+        keepalive_options[_TCP_KEEPCNT] = 3
     app["redis"] = await Redis.from_url(
         str(redis_url),
         socket_keepalive=True,
